Free Energy Minimization
========================

Quick Start
-----------
- Install ``fem``:

  .. code-block:: sh

     pip install fem


- Load ``fem`` in your Python script:

  .. code-block:: python

     import fem

Links
-----

Online documentation:
    http://lbm.niddk.nih.gov/mckennajp/fem

Python package index:
    https://pypi.python.org/pypi/fem

Source code repository:
    https://github.com/joepatmckenna/fem


